==> CGAL-5.1-doc_html.tar.xz: doc_html/Classification/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.1 - Classification", "index.html", [
    [ "User Manual", "index.html", [
      [ "Package Organization", "index.html#Classification_Organization", null ],
      [ "Common Data Structures", "index.html#Classification_structures", [
        [ "Label Set", "index.html#Classification_labels", null ],
        [ "Feature Set", "index.html#Classification_features", null ]
      ] ],
      [ "Specialized Data Structures", "index.html#Classification_structures_specialized", [
        [ "Point Set Classification", "index.html#Classification_point_sets", null ],
        [ "Mesh Classification", "index.html#Classification_meshes", null ],
        [ "Cluster Classification", "index.html#Classification_clusters", null ]
      ] ],
      [ "Classifiers", "index.html#Classification_classifiers", [
        [ "ETHZ Random Forest", "index.html#Classification_ETHZ_random_forest", null ],
        [ "OpenCV Random Forest", "index.html#Classification_OpenCV_random_forest", null ],
        [ "TensorFlow Neural Network", "index.html#Classification_TensorFlow_neural_network", null ],
        [ "Sum of Weighted Features", "index.html#Classification_sowf", [
          [ "Weights and Effects", "index.html#Classification_sowf_weights_effects", null ],
          [ "Training", "index.html#Classification_sowf_training", null ],
          [ "Result", "index.html#Classification_sowf_result", null ]
        ] ]
      ] ],
      [ "Classification Functions", "index.html#Classification_classification_functions", [
        [ "Raw Classification", "index.html#Classification_classify", null ],
        [ "Local Regularization", "index.html#Classification_smoothing", null ],
        [ "Global Regularization (Graph Cut)", "index.html#Classification_graphcut", null ]
      ] ],
      [ "Evaluation", "index.html#Classification_evaluation", null ],
      [ "Full Examples", "index.html#Classification_examples", [
        [ "Simple Point Set Classification", "index.html#Classification_example_general", null ],
        [ "Defining a Custom Feature", "index.html#Classification_example_feeature", null ],
        [ "Feature Generation and Training", "index.html#Classification_example_training", null ],
        [ "ETHZ Random Forest", "index.html#Classification_example_ethz_random_forest", null ],
        [ "OpenCV Random Forest", "index.html#Classification_example_opencv_random_forest", null ],
        [ "TensorFlow Neural Network", "index.html#Classification_example_tensorflow_neural_network", null ],
        [ "Mesh Classification", "index.html#Classification_example_mesh", null ],
        [ "Cluster Classification", "index.html#Classification_example_cluster", null ]
      ] ],
      [ "History", "index.html#Classification_history", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Classification_2example_classification_8cpp-example.html",
"group__PkgClassificationMain.html#gaea3ed82bf801bc9fbd00b63da48df73e"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.2-doc_html.tar.xz: doc_html/Classification/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2 - Classification", "index.html", [
    [ "User Manual", "index.html", [
      [ "Package Organization", "index.html#Classification_Organization", null ],
      [ "Common Data Structures", "index.html#Classification_structures", [
        [ "Label Set", "index.html#Classification_labels", null ],
        [ "Feature Set", "index.html#Classification_features", null ]
      ] ],
      [ "Specialized Data Structures", "index.html#Classification_structures_specialized", [
        [ "Point Set Classification", "index.html#Classification_point_sets", null ],
        [ "Mesh Classification", "index.html#Classification_meshes", null ],
        [ "Cluster Classification", "index.html#Classification_clusters", null ]
      ] ],
      [ "Classifiers", "index.html#Classification_classifiers", [
        [ "ETHZ Random Forest", "index.html#Classification_ETHZ_random_forest", [
          [ "Deprecated IO", "index.html#Classification_ETHZ_random_forest_deprecated", null ]
        ] ],
        [ "OpenCV Random Forest", "index.html#Classification_OpenCV_random_forest", null ],
        [ "TensorFlow Neural Network", "index.html#Classification_TensorFlow_neural_network", null ],
        [ "Sum of Weighted Features", "index.html#Classification_sowf", [
          [ "Weights and Effects", "index.html#Classification_sowf_weights_effects", null ],
          [ "Training", "index.html#Classification_sowf_training", null ],
          [ "Result", "index.html#Classification_sowf_result", null ]
        ] ]
      ] ],
      [ "Classification Functions", "index.html#Classification_classification_functions", [
        [ "Raw Classification", "index.html#Classification_classify", null ],
        [ "Local Regularization", "index.html#Classification_smoothing", null ],
        [ "Global Regularization (Graph Cut)", "index.html#Classification_graphcut", null ]
      ] ],
      [ "Evaluation", "index.html#Classification_evaluation", null ],
      [ "Full Examples", "index.html#Classification_examples", [
        [ "Simple Point Set Classification", "index.html#Classification_example_general", null ],
        [ "Defining a Custom Feature", "index.html#Classification_example_feeature", null ],
        [ "Feature Generation and Training", "index.html#Classification_example_training", null ],
        [ "ETHZ Random Forest", "index.html#Classification_example_ethz_random_forest", null ],
        [ "OpenCV Random Forest", "index.html#Classification_example_opencv_random_forest", null ],
        [ "TensorFlow Neural Network", "index.html#Classification_example_tensorflow_neural_network", null ],
        [ "Mesh Classification", "index.html#Classification_example_mesh", null ],
        [ "Cluster Classification", "index.html#Classification_example_cluster", null ]
      ] ],
      [ "History", "index.html#Classification_history", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Classification_2example_classification_8cpp-example.html",
"classCGAL_1_1Classification_1_1Sum__of__weighted__features__classifier.html#a0156222de02089c8f104359bf64bd16e"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
